Package: brolgar
Title: Browse Over Longitudinal Data Graphically and Analytically in R
Version: 1.0.1
Authors@R: 
    c(person(given = "Nicholas",
             family = "Tierney",
             role = c("aut", "cre"),
             email = "nicholas.tierney@gmail.com",
             comment = c(ORCID = "https://orcid.org/0000-0003-1460-8722")),
      person(given = "Di",
             family = "Cook",
             role = "aut",
             email = "dicook@monash.edu",
             comment = c(ORCID = "https://orcid.org/0000-0002-3813-7155")),
      person(given = "Tania",
             family = "Prvan",
             role = "aut",
             email = "tania.prvan@mq.edu.au"),
      person(given = "Stuart",
             family = "Lee",
             role = "ctb"),
      person(given = "Earo",
             family = "Wang",
             role = "ctb"))
Description: Provides a framework of tools to summarise, visualise, and explore 
  longitudinal data. It builds upon the tidy time series data frames used in the
  'tsibble' package, and is designed to integrate within the 'tidyverse', and
  'tidyverts' (for time series) ecosystems. The methods implemented include 
  calculating features for understanding longitudinal data, including 
  calculating summary statistics such as quantiles, medians, and numeric ranges,
  sampling individual series, identifying individual series representative of a 
  group, and extending the facet system  in 'ggplot2' to facilitate exploration of samples of data. These methods are
  fully described in the paper "brolgar: An R package to Browse Over 
  Longitudinal Data Graphically and Analytically in R", Nicholas Tierney, 
  Dianne Cook, Tania Prvan (2020) <doi:10.32614/RJ-2022-023>.
License: MIT + file LICENSE
URL: https://github.com/njtierney/brolgar,
        https://brolgar.njtierney.com/
BugReports: https://github.com/njtierney/brolgar/issues
Depends: R (>= 3.5.0)
Imports: dplyr (>= 0.8.3), fabletools, ggplot2 (>= 3.2.0), glue (>=
        1.3.1), magrittr (>= 1.5), purrr (>= 0.3.2), rlang (>= 0.4.0),
        stats, tibble (>= 2.1.3), tidyr (>= 0.8.3), tsibble (>= 0.8.2),
        vctrs
Suggests: gapminder, gghighlight (>= 0.1.0), knitr (>= 1.23), Matrix
        (>= 1.6-5), lme4, modelr, rmarkdown (>= 1.14), spelling (>=
        2.1), testthat (>= 3.0.0), tsibbledata, vdiffr (>= 0.3.1)
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.1
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-05-10 07:57:20 UTC; nick
Author: Nicholas Tierney [aut, cre] (<https://orcid.org/0000-0003-1460-8722>),
  Di Cook [aut] (<https://orcid.org/0000-0002-3813-7155>),
  Tania Prvan [aut],
  Stuart Lee [ctb],
  Earo Wang [ctb]
Maintainer: Nicholas Tierney <nicholas.tierney@gmail.com>
Repository: CRAN
Date/Publication: 2024-05-10 14:50:34 UTC
Built: R 4.2.3; ; 2024-05-10 16:29:20 UTC; unix
