# Generated by roxygen2: do not edit by hand

S3method(index_regular,data.frame)
S3method(index_regular,tbl_ts)
S3method(index_summary,data.frame)
S3method(index_summary,tbl_ts)
S3method(key_slope,tbl_ts)
S3method(keys_near,data.frame)
S3method(keys_near,default)
S3method(keys_near,tbl_ts)
S3method(sample_frac_keys,tbl_ts)
S3method(sample_n_keys,tbl_ts)
S3method(stratify_keys,tbl_ts)
export("%>%")
export(add_key_slope)
export(add_key_slope.default)
export(add_n_obs)
export(as_tsibble)
export(b_diff_iqr)
export(b_diff_max)
export(b_diff_mean)
export(b_diff_median)
export(b_diff_min)
export(b_diff_q25)
export(b_diff_q75)
export(b_diff_sd)
export(b_diff_var)
export(b_iqr)
export(b_mad)
export(b_max)
export(b_mean)
export(b_median)
export(b_min)
export(b_q25)
export(b_q75)
export(b_range)
export(b_range_diff)
export(b_sd)
export(b_var)
export(decreasing)
export(facet_sample)
export(facet_strata)
export(feat_brolgar)
export(feat_diff_summary)
export(feat_five_num)
export(feat_monotonic)
export(feat_ranges)
export(feat_spread)
export(feat_three_num)
export(features)
export(features_all)
export(features_at)
export(features_if)
export(increasing)
export(index_regular)
export(index_summary)
export(key_slope)
export(keys_near)
export(l_five_num)
export(l_three_num)
export(monotonic)
export(n_keys)
export(n_obs)
export(near_between)
export(near_middle)
export(near_quantile)
export(nearest_lgl)
export(nearest_qt_lgl)
export(sample_frac_keys)
export(sample_n_keys)
export(stratify_keys)
export(unvarying)
import(ggplot2)
importFrom(fabletools,features)
importFrom(fabletools,features_all)
importFrom(fabletools,features_at)
importFrom(fabletools,features_if)
importFrom(magrittr,"%>%")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,enquo)
importFrom(rlang,enquos)
importFrom(rlang,ensym)
importFrom(rlang,quo)
importFrom(rlang,quo_name)
importFrom(rlang,quos)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(tsibble,as_tsibble)
importFrom(tsibble,n_keys)
